#include <stdio.h>
#include <math.h>
#include <cairo.h>
#include <cairo-svg.h>

int main(void)
{
	cairo_surface_t *recording_surface;
	cairo_surface_t *svg_target;
	cairo_surface_t *image_target;
	cairo_t *cr;
	cairo_t *svg_cr;
	cairo_t *image_cr;
	double x0;
	double y0;
	double width;
	double height;
	double x;
	double y;
	int use_offset;

	recording_surface = cairo_recording_surface_create(CAIRO_CONTENT_COLOR_ALPHA, NULL);
	cr = cairo_create(recording_surface);

	cairo_set_source_rgb(cr, 1, 0, 0);
	cairo_set_line_width(cr, 2);

	cairo_move_to(cr, 0, 0);
	/* move right */
	cairo_rel_line_to(cr, 10, 0);
	/* move down */
	cairo_rel_line_to(cr, 0, 10);
	/* move left */
	cairo_rel_line_to(cr, -10, 0);
	/* move left again, draw to negative extents */
	cairo_rel_line_to(cr, -10, 0);
	cairo_stroke(cr);

	cairo_recording_surface_ink_extents(recording_surface, &x0, &y0,
					    &width, &height);

	printf("x0: %lf y0: %lf width: %lf height: %lf\n", x0, y0, width, height);

	/* offset the source surface in order to draw all of it */
	use_offset = 1;
	if (use_offset) {
		x = -x0;
		y = -y0;
	} else {
		x = 0;
		y = 0;
	}

	/* Saving to PNG */
	image_target = cairo_image_surface_create(CAIRO_FORMAT_ARGB32, width, height);
	image_cr = cairo_create(image_target);
	cairo_set_source_surface(image_cr, recording_surface, x, y);
	cairo_paint(image_cr);
	cairo_destroy(image_cr);
	cairo_surface_write_to_png(image_target, "c.png");
	cairo_surface_destroy(image_target);

	/* Saving to SVG does not seem right */
	svg_target = cairo_svg_surface_create("c.svg", width, height);
	svg_cr = cairo_create(svg_target);
	cairo_set_source_surface(svg_cr, recording_surface, x, y);
	cairo_paint(svg_cr);
	cairo_destroy(svg_cr);
	cairo_surface_destroy(svg_target);

	cairo_destroy(cr);
	cairo_surface_destroy(recording_surface);

	return 0;
}
